EasySupportConfig class

Constructors

EasySupportConfig({required String baseUrl, required String channelToken, String? apiBaseUrl, String? channelKey, String? widgetTitle, String? webViewUrl, bool autoOpen = true, bool isEmojiEnabled = true, bool isMediaEnabled = true, bool useWebSocketChannel = false, String? webSocketChannelUrl, bool webSocketChannelSocketIoMode = false, String? socketPath, String? socketNamespace, List<String> socketTransports = const <String>['websocket', 'polling'], Map<String, dynamic> socketQuery = const <String, dynamic>{}, Map<String, dynamic> socketAuth = const <String, dynamic>{}, Map<String, String> additionalHeaders = const <String, String>{}})
const
EasySupportConfig.essentials({required String baseUrl, required String channelToken})
const
EasySupportConfig.fromJson(Map<String, dynamic> json)
factory

Properties

additionalHeaders Map<String, String>
final
apiBaseUrl String?
final
autoOpen bool
final
baseUrl String
final
channelKey String?
final
channelToken String
final
hashCode int
The hash code for this object.
no setterinherited
isEmojiEnabled bool
final
isMediaEnabled bool
final
normalizedApiBaseUrl String
no setter
normalizedBaseUrl String
no setter
resolvedHeaders Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketAuth Map<String, dynamic>
final
socketNamespace String?
final
socketPath String?
final
socketQuery Map<String, dynamic>
final
socketTransports List<String>
final
useWebSocketChannel bool
final
webSocketChannelSocketIoMode bool
final
webSocketChannelUrl String?
final
webViewUrl String?
final
widgetTitle String?
final

Methods

copyWith({String? baseUrl, String? channelToken, String? apiBaseUrl, String? channelKey, String? widgetTitle, String? webViewUrl, bool? autoOpen, bool? isEmojiEnabled, bool? isMediaEnabled, bool? useWebSocketChannel, String? webSocketChannelUrl, bool? webSocketChannelSocketIoMode, String? socketPath, String? socketNamespace, List<String>? socketTransports, Map<String, dynamic>? socketQuery, Map<String, dynamic>? socketAuth, Map<String, String>? additionalHeaders}) EasySupportConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJavaScriptOptions() Map<String, dynamic>
toJavaScriptOptionsJson() String
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited